DataLoader<T> typedef

DataLoader<T> = AsyncData<T> Function(BuildContext context)

A context-aware async data producer used by Unrouter widgets.

A data loader is usually created once and called from a widget tree to obtain an AsyncData snapshot for the current BuildContext.

Implementation

typedef DataLoader<T> = AsyncData<T> Function(BuildContext context);