RouteScopeProvider class
Inherited route scope used by route hooks and Outlet.
This provider is injected by the router delegate for the currently matched route record and updated whenever the active location changes.
Example:
class UserPage extends StatelessWidget {
@override
Widget build(BuildContext context) {
final params = useRouteParams(context);
final id = params.required('id');
return Text('User $id');
}
}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- InheritedModel<
RouteScope> - RouteScopeProvider
Constructors
-
RouteScopeProvider({Key? key, required Widget child, required RouteRecord<
Widget> route, required RouteParams params, required HistoryLocation location, required URLSearchParams query, HistoryLocation? fromLocation}) -
Creates a route scope provider.
const
Properties
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- fromLocation → HistoryLocation?
-
Previous accepted location.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- location → HistoryLocation
-
Current location (
URI + state).final - params → RouteParams
-
Matched params for the current route.
final
- query → URLSearchParams
-
Query params for the current route.
final
-
route
→ RouteRecord<
Widget> -
Compiled route record for the current path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedModelElement< RouteScope> -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
isSupportedAspect(
Object aspect) → bool -
Returns true if this model supports the given
aspect.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant RouteScopeProvider oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
-
updateShouldNotifyDependent(
covariant RouteScopeProvider oldWidget, Set< RouteScope> dependencies) → bool -
Return true if the changes between this model and
oldWidgetmatch any of thedependencies.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context, RouteScope scope) → RouteScopeProvider -
Looks up the nearest RouteScopeProvider for a specific
scopeaspect.