OutletScope class
Inherited scope used by Outlet to resolve nested views by depth.
Constructors
-
OutletScope({required Component child, required List<
ViewBuilder> views, required int depth, Key? key}) -
Creates an outlet scope.
const
Properties
- child → Component
-
finalinherited
- depth → int
-
Zero-based depth for the next Outlet lookup.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
views
→ List<
ViewBuilder> -
Ordered view builders for the matched route chain.
final
Methods
-
createElement(
) → InheritedElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant OutletScope oldComponent) → bool - Whether the framework should notify components that inherit from this component.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → OutletScope -
Looks up the nearest OutletScope from
context.