RouterView class
Renders the currently matched Unrouter route chain in a Nocterm app.
Constructors
- RouterView({required Unrouter router, Key? key})
-
Creates a Nocterm routing view.
const
Properties
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< RouterView> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited