ViewBuilder typedef
ViewBuilder =
ViewBuilder<Component>
Builds a Nocterm component for a matched route segment.
Implementation
typedef ViewBuilder = core.ViewBuilder<Component>;
Builds a Nocterm component for a matched route segment.
typedef ViewBuilder = core.ViewBuilder<Component>;