useLocation function
Returns the current location from the nearest route scope.
Implementation
HistoryLocation useLocation(BuildContext context) {
return RouteScopeProvider.of(context).location;
}
Returns the current location from the nearest route scope.
HistoryLocation useLocation(BuildContext context) {
return RouteScopeProvider.of(context).location;
}