HistoryLocation class

The current location for a History implementation.

Constructors

HistoryLocation(Uri uri, [Object? state])
const

Properties

fragment String
no setter
hashCode int
The hash code for this object.
no setterinherited
path String
no setter
query String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Object?
final
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited