Inlet class
Flutter route declaration used by createRouter.
Constructors
Properties
-
children
→ Iterable<
RouteNode< Widget> > -
Child routes nested under this route segment.
finalinherited
-
guards
→ Iterable<
Guard> -
Guards evaluated after global guards for this route.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
meta
→ Map<
String, Object?> ? -
Route metadata merged from parent to child.
finalinherited
- name → String?
-
Route-name alias used by navigation APIs.
finalinherited
- path → String
-
Route segment pattern for this node.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
view
→ ViewBuilder<
Widget> -
View builder rendered when this route segment matches.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited