RouteScope enum
Aspects used by RouteScopeProvider for selective rebuilds.
Each hook subscribes only to the aspect it needs so unrelated navigation updates do not trigger unnecessary widget rebuilds.
Values
- meta → const RouteScope
-
Route metadata.
- params → const RouteScope
-
Route params.
- query → const RouteScope
-
Query params.
- uri → const RouteScope
-
URI only.
- state → const RouteScope
-
Navigation state only.
- location → const RouteScope
-
Full location (
uri + state). - from → const RouteScope
-
Previous location.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RouteScope> - A constant List of the values in this enum, in order of their declaration.