RouteScopeProvider class
Inherited route scope used by route hooks and Outlet.
Constructors
-
RouteScopeProvider({Key? key, required Component child, required Unrouter router, required RouteRecord<
Component> route, required RouteParams params, required HistoryLocation location, required URLSearchParams query, HistoryLocation? fromLocation}) -
Creates a route scope provider.
const
Properties
- child → Component
-
finalinherited
- fromLocation → HistoryLocation?
-
Previous accepted location.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- location → HistoryLocation
-
Current location.
final
- params → RouteParams
-
Matched params for the current route.
final
- query → URLSearchParams
-
Query params for the current route.
final
-
route
→ RouteRecord<
Component> -
Compiled route record for the current path.
final
- router → Unrouter
-
Active router instance for the current routed subtree.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant RouteScopeProvider oldComponent) → bool - Whether the framework should notify components that inherit from this component.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → RouteScopeProvider -
Looks up the nearest RouteScopeProvider from
context.